<?xml version="1.0" encoding="utf-8"?>

<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:optim="http://www.ibm.com/optim/audit/v11.3.0.0"
	xmlns:optimreport="http://www.ibm.com/optim/report/v11.3.0.0"
	xmlns:optimcommon="http://www.ibm.com/optim/common/v11.3.0.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">
	<xsl:import href="BarActionTemplate.xsl"/>
	<xsl:import href="Style.xsl"/>
	<xsl:import href="ReportOverview.xsl"/>
	<xsl:import href="ReportSummary.xsl"/>
	<xsl:import href="CommonTemplates.xsl"/>
	<xsl:import href="ArchiveReport.xsl"/>
	<xsl:import href="CompareReport.xsl"/>
	<xsl:import href="ConvertReport.xsl"/>
	<xsl:import href="DeleteReport.xsl"/>
	<xsl:import href="ExtractReport.xsl"/>
	<xsl:import href="InsertReport.xsl"/>
	<xsl:import href="LoadReport.xsl"/>
	<xsl:import href="RestoreReport.xsl"/>
	<xsl:import href="ReportReport.xsl"/>
	<xsl:import href="InsertDDL.xsl"/>
	<xsl:import href="LoadMessage.xsl"/>

	<xsl:import href="ReportOverrides.xsl"/>
	<xsl:import href="ReportRequestOptions.xsl"/>
	<xsl:import href="Parameters.xsl"/>

	<xsl:output method="html" indent="yes" version="4.0"
		doctype-public="-//W3C//DTD HTML 4.01//EN" doctype-system="http://www.w3.org/TR/html4/strict.dtd" />

	<xsl:template match="/">
		<xsl:apply-templates />
	</xsl:template>

	<!-- BEGIN REPORT MAIN -->
	<xsl:template match="optimreport:OptimReport | optimreport:OptimExceptionReport">
		<html>
			<head>
				<!-- Javascript functions to add utility to the report -->
				<script type="text/javascript" src="/functions.js">
					&#160;
				</script>
				<!-- END Javascript functions to add utility to the report -->
				<title>
					<xsl:value-of select="@reportTitle" />
					<xsl:text>-</xsl:text>
					<xsl:value-of
						select=".//optimreport:request/@name" />
				</title>
				<!-- embed the stylesheet here to solve the link location problem -->

				<!-- Embedded CSS -->
				<xsl:call-template name="Style" />
				<!-- END Embedded CSS -->

				<!--BEGIN JAVASCRIPT FUNCTIONS-->
				<xsl:call-template name="JSFunctions" />
				<!--END JAVASCRIPT FUNCTIONS-->
			</head>

			<body class="oneui">
				<!-- Report Banner -->
				<div class="header" name="page_header">
					<div class="first_header_shell">
						<div class="header_primary resizeWindow">
							<h1 class="header_text" align="left">
								<xsl:value-of select="optimreport:CommonContent/optimreport:solution/@name" />
							</h1>
							<div style="margin-top:-26px">
								<!-- <img class="ibm_logo" src="images/ibm-logo-white.gif"></img> -->
								<img id="ibm-logo-white.gif" class="ibm_logo"
									src="data:image/gif;base64,R0lGODlhKQAPAJEAAAAAAP///////wAAACH5BAEAAAIALAAAAAApAA8AAAJFjB+CK80NH5y02ovdSpvt+WXiSCoGdUSnlpptCcdqAnZ198r6mLuh6wPuhpne63hCCInMmRKXeqwktGaJY4M6aVOlQ1AAADs=" />
							</div>
						</div>
					</div>
					<!-- Only show in the regular report, not in minimal report -->
					<div class="second_header_shell">
						<div class="header_secondary resizeWindow">
							<div class="sec_header_title">
								<h1 class="sec_header_text" align="left">
									<xsl:value-of select="@reportTitle" />
								</h1>
							</div>

							<xsl:if test="not(contains(name(.), 'Exception'))">
								<div class="page_action">
									<div>
										<a href="" onclick="toggleAllSections('c', event)">Collapse All</a>
									</div>
									<div>
										|
									</div>
									<div>
										<a href="" onclick="toggleAllSections('e', event)">Expand All</a>
									</div>
								</div>
							</xsl:if>
						</div>
					</div>	
				</div>
				<!-- END Report Banner -->

				<xsl:choose>
					<xsl:when test="contains(name(.), 'Exception')">
						<xsl:apply-templates select="optimreport:CommonContent" />
					</xsl:when>
					<xsl:otherwise>
						<div class="report_content resizeWindow" media="print">
							<!-- BEGIN Table of Contents -->
							<div class="report_content_block">
								<div class="table_of_content_header clearfix">
									<div class="table_of_content_header_text_block">
										<h2 class="table_of_contents_header_text">
											Report Contents
										</h2>
									</div>
									<div class="report_version_block ">
										<div class="report_version_block_title" >
											<a class="report_version_block_link" href="#JSLanding" onclick="toggle('', 'report_version_block_detailblock_class', event);swap('report_version_arrow', 'report_version_block_detailblock', event)">
												<img class="blockArrow" id="report_version_arrow" inSwapAction="true" src="data:image/gif;base64,R0lGODlhBQAJAIAAAP///3l5eSH5BAEHAAAALAAAAAAFAAkAAAIMDA5hp9v2YlJsJQQKADs=">
												</img>
											</a>
											<div class="report_version_block_title_text">
												<a href=""  onclick="toggle('', 'report_version_block_detailblock_class', event);swap('report_version_arrow', 'report_version_block_detailblock', event)">
													<xsl:text>Directory: </xsl:text>
													<xsl:value-of select="optimreport:CommonContent/optimreport:directory/@name"/>
												</a>
											</div>
										</div>
										<div id="report_version_block_detailblock" class="report_version_block_detailblock_class" style="display:none" inAllAction="true">
											<div class="report_version_block_details">
												<b>
													<xsl:text>Vendor: </xsl:text>
												</b>
												<xsl:call-template name="stringCheck">
													<xsl:with-param name="value" select="optimreport:CommonContent/optimreport:directory/@databaseVendor"/>
												</xsl:call-template>
											</div>
											<div class="report_version_block_details">
												<b>
													<xsl:text>Version: </xsl:text>
												</b>
												<xsl:call-template name="stringCheck">
													<xsl:with-param name="value" select="optimreport:CommonContent/optimreport:directory/@databaseVersion"/>
												</xsl:call-template>
											</div>
											<div class="report_version_block_details">
												<b>
													<xsl:text>Description: </xsl:text>
												</b>
												<xsl:choose>
													<xsl:when test="string-length(optimreport:CommonContent/optimreport:directory/@description)!=0">
														<xsl:value-of select="optimreport:CommonContent/optimreport:directory/@description"/>
													</xsl:when>
													<xsl:otherwise>
														<xsl:text>(None)</xsl:text>
													</xsl:otherwise>
												</xsl:choose>
											</div>
										</div>
									</div>
								</div>
								<div class="report_content_table_list">
									<ol>
										<xsl:choose>
											<xsl:when test="contains(@reportType, 'Restore') or contains(@reportType, 'restore')">
												<xsl:call-template name="singleMenuItem">
													<xsl:with-param name="anchor">stats</xsl:with-param>
													<xsl:with-param name="containerClass">overview_container_class</xsl:with-param>
													<xsl:with-param name="containerId">overview_container</xsl:with-param>
													<xsl:with-param name="sectionName">Overview</xsl:with-param>
												</xsl:call-template>

												<xsl:for-each select="./*[contains(name(.), 'Report') and not(contains(name(.), 'Reports'))]">
													<!-- Set Report Name -->
													<li class="common_link_to_section">
														<xsl:call-template name="tableContentName">
															<xsl:with-param name="name" select="name(.)"/>
														</xsl:call-template>
													</li>
													<!-- Set all content list -->
													<xsl:call-template name="tableOfContents"/>
												</xsl:for-each>
											</xsl:when>
											<xsl:when test="*[contains(name(.), 'ReportProcessReport')]">
												<xsl:call-template name="singleMenuItem">
													<xsl:with-param name="anchor">stats</xsl:with-param>
													<xsl:with-param name="containerClass">overview_container_class</xsl:with-param>
													<xsl:with-param name="containerId">overview_container</xsl:with-param>
													<xsl:with-param name="sectionName">Overview</xsl:with-param>
													<xsl:with-param name="isNested">false</xsl:with-param>
												</xsl:call-template>

												<xsl:call-template name="ContentTableWithoutNestedReport"/>
											</xsl:when>
											<xsl:when test="*//*[contains(name(.), 'Report') and not(contains(name(.), 'Reports'))] and not(contains(@reportType, 'Report'))">
												<xsl:call-template name="singleMenuItem">
													<xsl:with-param name="anchor">stats</xsl:with-param>
													<xsl:with-param name="containerClass">overview_container_class</xsl:with-param>
													<xsl:with-param name="containerId">overview_container</xsl:with-param>
													<xsl:with-param name="sectionName">Overview</xsl:with-param>
												</xsl:call-template>

												<xsl:call-template name="ContentTableOfNestedReport"/>
											</xsl:when>
											<xsl:otherwise>
												<xsl:call-template name="singleMenuItem">
													<xsl:with-param name="anchor">stats</xsl:with-param>
													<xsl:with-param name="containerClass">overview_container_class</xsl:with-param>
													<xsl:with-param name="containerId">overview_container</xsl:with-param>
													<xsl:with-param name="sectionName">Overview</xsl:with-param>
													<xsl:with-param name="isNested">false</xsl:with-param>
												</xsl:call-template>

												<xsl:call-template name="ContentTableWithoutNestedReport"/>
											</xsl:otherwise>
										</xsl:choose>
									</ol>
								</div>
							</div>
							<!-- END Table of Contents -->
							<xsl:apply-templates select="optimreport:CommonContent" />

							<!-- Apply all templates, we can only possibly be looking at one report type. 	-->
							<!-- XSL is smart enough to know which one is the correct one.			      	-->
							<!-- This has no impact on reports within reports. Templates will have to apply -->
							<!-- the report type it would like to include within it. 					    -->
							<xsl:apply-templates select="optimreport:ArchiveReport" />
							<xsl:apply-templates select="optimreport:CompareReport" />
							<xsl:apply-templates select="optimreport:ConvertReport" />
							<xsl:apply-templates select="optimreport:DeleteReport" />
							<xsl:apply-templates select="optimreport:ExtractReport" />
							<xsl:apply-templates select="optimreport:InsertReport" />
							<xsl:apply-templates select="optimreport:LoadReport" />
							<xsl:apply-templates select="optimreport:RestoreReport" />
							<xsl:apply-templates select="optimreport:ReportProcessReport"/>

							<!-- Overrides Section -->
							<xsl:apply-templates select="optimreport:overrides" />
							
							<div  class="back_to_top" id="back_to_top_block" media="print">
								<a href="#">Top</a>
							</div>
						</div>
					</xsl:otherwise>
				</xsl:choose>
				<br/>

			</body>
		</html>
	</xsl:template>
	<!-- END REPORT MAIN -->

	<!-- BEGIN Common Content Template -->
	<xsl:template match="optimreport:CommonContent">
		<xsl:apply-templates select="optimreport:overview[@*]"/>
	</xsl:template>
	<!-- END Common Content Template -->

	<xsl:include href="JavaScriptFunctions.xsl"/>
</xsl:stylesheet>

